# Copyright (c) Facebook, Inc. and its affiliates.

# This source code is licensed under the MIT license found in the
# LICENSE file in the root directory of this source tree.


#' Generated table of holiday dates at the country level from 1995 to 2045
#'
#' The data is primarily based on the Python package [holidays](https://pypi.org/project/holidays/)
#'
#' @format A data frame with four variables: ds, holiday, country, year
#' @source \url{https://github.com/facebook/prophet/blob/main/python/scripts/generate_holidays_file.py}
#' @export
"generated_holidays"
