% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/prophet.R
\name{validate_inputs}
\alias{validate_inputs}
\title{Validates the inputs to Prophet.}
\usage{
validate_inputs(m)
}
\arguments{
\item{m}{Prophet object.}
}
\value{
The Prophet object.
}
\description{
Validates the inputs to Prophet.
}
\keyword{internal}
